From 9ae8c7a2886dcdd9c142710e1dc044e538675784 Mon Sep 17 00:00:00 2001
From: Jeremy Huddleston Sequoia <jeremyhu@apple.com>
Date: Sat, 17 Jan 2015 09:03:43 -0800
Subject: [PATCH 5/5] Set the Mach-O CPU Subtype to ppc7400 when targeting
 Leopard

http://llvm.org/bugs/show_bug.cgi?id=18463

Signed-off-by: Jeremy Huddleston Sequoia <jeremyhu@apple.com>
(cherry picked from commit 53f17b9930d8ace72f8a8f241bc54ce65e29ecd0)
---
 lib/Target/PowerPC/MCTargetDesc/PPCAsmBackend.cpp | 14 +++++++++++---
 1 file changed, 11 insertions(+), 3 deletions(-)

diff --git llvm_release_35/lib/Target/PowerPC/MCTargetDesc/PPCAsmBackend.cpp macports_release_35/lib/Target/PowerPC/MCTargetDesc/PPCAsmBackend.cpp
index c54d5e7..21f1f8f 100644
--- llvm_release_35/lib/Target/PowerPC/MCTargetDesc/PPCAsmBackend.cpp
+++ macports_release_35/lib/Target/PowerPC/MCTargetDesc/PPCAsmBackend.cpp
@@ -205,16 +205,23 @@ public:
 // FIXME: This should be in a separate file.
 namespace {
   class DarwinPPCAsmBackend : public PPCAsmBackend {
+    Triple TheTriple;
   public:
-    DarwinPPCAsmBackend(const Target &T) : PPCAsmBackend(T, false) { }
+    DarwinPPCAsmBackend(const Target &T, StringRef TT) : PPCAsmBackend(T, false), TheTriple(TT) { }
 
     MCObjectWriter *createObjectWriter(raw_ostream &OS) const override {
       bool is64 = getPointerSize() == 8;
+      MachO::CPUSubTypePowerPC CS = MachO::CPU_SUBTYPE_POWERPC_ALL;
+
+      if (TheTriple.isOSDarwin() && !TheTriple.isMacOSXVersionLT(10,5)) {
+          CS = MachO::CPU_SUBTYPE_POWERPC_7400;
+      }
+
       return createPPCMachObjectWriter(
           OS,
           /*Is64Bit=*/is64,
           (is64 ? MachO::CPU_TYPE_POWERPC64 : MachO::CPU_TYPE_POWERPC),
-          MachO::CPU_SUBTYPE_POWERPC_ALL);
+          CS);
     }
   };
 
@@ -236,8 +243,9 @@ namespace {
 MCAsmBackend *llvm::createPPCAsmBackend(const Target &T,
                                         const MCRegisterInfo &MRI,
                                         StringRef TT, StringRef CPU) {
+
   if (Triple(TT).isOSDarwin())
-    return new DarwinPPCAsmBackend(T);
+    return new DarwinPPCAsmBackend(T, TT);
 
   uint8_t OSABI = MCELFObjectTargetWriter::getOSABI(Triple(TT).getOS());
   bool IsLittleEndian = Triple(TT).getArch() == Triple::ppc64le;
-- 
2.2.2

